@@ -2,7 +2,7 @@ use Object::Pad ':experimental( init_expr mop )';
 
 package OpenTelemetry::SDK::Trace::Span;
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 use OpenTelemetry;
 my $logger = OpenTelemetry->logger;
@@ -152,11 +152,7 @@ class OpenTelemetry::SDK::Trace::Span
         $time //= time;
 
         return $self unless $lock->enter( sub {
-            unless ($self->recording) {
-                $logger->warn('Calling end on an ended Span');
-                return;
-            }
-
+            return unless $self->recording;
             $end = $time;
         });
 
